@@ -27,7 +27,7 @@ import os
 from pysollib.gamedb import GI
 from pysollib.help import help_about, help_html
 from pysollib.mfxutil import Struct, openURL
-from pysollib.mfxutil import print_err
+from pysollib.mfxutil import USE_PIL, print_err
 from pysollib.mygettext import _
 from pysollib.pysolrandom import construct_random
 from pysollib.pysoltk import AllGames_StatsDialog, SingleGame_StatsDialog
@@ -77,6 +77,7 @@ class PysolMenubar(PysolMenubarTk):
             quickplay=0,
             demo=0,
             highlight_piles=0,
+            autoscale=0,
             find_card=0,
             rules=0,
             pause=0,
@@ -151,6 +152,8 @@ class PysolMenubar(PysolMenubarTk):
             ms.quickplay = 1
         if opt.highlight_piles and game.getHighlightPilesStacks():
             ms.highlight_piles = 1
+        if opt.auto_scale:
+            ms.autoscale = 1
         if game.canFindCard():
             ms.find_card = 1
         if game.app.getGameRulesFilename(game.id):  # note: this may return ""
@@ -179,6 +182,7 @@ class PysolMenubar(PysolMenubarTk):
         self.updateBookmarkMenuState()
         self.setMenuState(ms.restart, "edit.restart")
         self.setMenuState(ms.custom_game, "edit.editcurrentgame")
+        self.setMenuState(ms.custom_game, "edit.deletecurrentgame")
         # Game menu
         self.setMenuState(ms.deal, "game.dealcards")
         self.setMenuState(ms.autodrop, "game.autodrop")
@@ -195,6 +199,15 @@ class PysolMenubar(PysolMenubarTk):
         self.setMenuState(ms.autodrop, "options.automaticplay.autodrop")
         self.setMenuState(ms.autodeal, "options.automaticplay.autodeal")
         self.setMenuState(ms.quickplay, "options.automaticplay.quickplay")
+        if USE_PIL:
+            self.setMenuState(ms.autoscale,
+                              "options.cardsize.preserveaspectratio")
+            self.setMenuState(not ms.autoscale,
+                              "options.cardsize.increasethecardsize")
+            self.setMenuState(not ms.autoscale,
+                              "options.cardsize.decreasethecardsize")
+            self.setMenuState(not ms.autoscale,
+                              "options.cardsize.resetthecardsize")
         # Help menu
         self.setMenuState(ms.rules, "help.rulesforthisgame")
         # Toolbar
