@@ -1,108 +1,112 @@
-#!/usr/bin/env python2
+#!/usr/bin/env python
 # -*- mode: python; coding: utf-8; -*-
-##---------------------------------------------------------------------------##
-##
-## Copyright (C) 1998-2003 Markus Franz Xaver Johannes Oberhumer
-## Copyright (C) 2003 Mt. Hood Playing Card Co.
-## Copyright (C) 2005-2009 Skomoroh
-##
-## This program is free software: you can redistribute it and/or modify
-## it under the terms of the GNU General Public License as published by
-## the Free Software Foundation, either version 3 of the License, or
-## (at your option) any later version.
-##
-## This program is distributed in the hope that it will be useful,
-## but WITHOUT ANY WARRANTY; without even the implied warranty of
-## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-## GNU General Public License for more details.
-##
-## You should have received a copy of the GNU General Public License
-## along with this program.  If not, see <http://www.gnu.org/licenses/>.
-##
-##---------------------------------------------------------------------------##
+# ---------------------------------------------------------------------------##
+#
+#  Copyright (C) 1998-2003 Markus Franz Xaver Johannes Oberhumer
+#  Copyright (C) 2003 Mt. Hood Playing Card Co.
+#  Copyright (C) 2005-2009 Skomoroh
+#
+#  This program is free software: you can redistribute it and/or modify
+#  it under the terms of the GNU General Public License as published by
+#  the Free Software Foundation, either version 3 of the License, or
+#  (at your option) any later version.
+#
+#  This program is distributed in the hope that it will be useful,
+#  but WITHOUT ANY WARRANTY; without even the implied warranty of
+#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+#  GNU General Public License for more details.
+#
+#  You should have received a copy of the GNU General Public License
+#  along with this program.  If not, see <http://www.gnu.org/licenses/>.
+#
+# ---------------------------------------------------------------------------##
 
 
-# imports
 import imp
 
-# PySol imports
-from mfxutil import Struct, print_err
-from resource import CSI
-import settings
+import pysollib.settings
+from pysollib.mfxutil import Struct, print_err
+from pysollib.mygettext import _, n_
+from pysollib.resource import CSI
 
+import six
 
 # ************************************************************************
 # * constants
 # ************************************************************************
 
+
 # GameInfo constants
 class GI:
     # game category - these *must* match the cardset CSI.TYPE_xxx
-    GC_FRENCH        = CSI.TYPE_FRENCH
-    GC_HANAFUDA      = CSI.TYPE_HANAFUDA
-    GC_TAROCK        = CSI.TYPE_TAROCK
-    GC_MAHJONGG      = CSI.TYPE_MAHJONGG
-    GC_HEXADECK      = CSI.TYPE_HEXADECK
+    GC_FRENCH = CSI.TYPE_FRENCH
+    GC_HANAFUDA = CSI.TYPE_HANAFUDA
+    GC_TAROCK = CSI.TYPE_TAROCK
+    GC_MAHJONGG = CSI.TYPE_MAHJONGG
+    GC_HEXADECK = CSI.TYPE_HEXADECK
     GC_MUGHAL_GANJIFA = CSI.TYPE_MUGHAL_GANJIFA
     GC_NAVAGRAHA_GANJIFA = CSI.TYPE_NAVAGRAHA_GANJIFA
     GC_DASHAVATARA_GANJIFA = CSI.TYPE_DASHAVATARA_GANJIFA
-    GC_TRUMP_ONLY    = CSI.TYPE_TRUMP_ONLY
+    GC_TRUMP_ONLY = CSI.TYPE_TRUMP_ONLY
 
     # game type
-    GT_1DECK_TYPE   = 0
-    GT_2DECK_TYPE   = 1
-    GT_3DECK_TYPE   = 2
-    GT_4DECK_TYPE   = 3
+    GT_1DECK_TYPE = 0
+    GT_2DECK_TYPE = 1
+    GT_3DECK_TYPE = 2
+    GT_4DECK_TYPE = 3
     GT_BAKERS_DOZEN = 4
     GT_BELEAGUERED_CASTLE = 5
-    GT_CANFIELD     = 6
+    GT_CANFIELD = 6
     GT_DASHAVATARA_GANJIFA = 7
-    GT_FAN_TYPE     = 8
+    GT_FAN_TYPE = 8
     GT_FORTY_THIEVES = 9
-    GT_FREECELL     = 10
-    GT_GOLF         = 11
-    GT_GYPSY        = 12
-    GT_HANAFUDA     = 13
-    GT_HEXADECK     = 14
-    GT_KLONDIKE     = 15
-    GT_MAHJONGG     = 16
-    GT_MATRIX       = 17
-    GT_MEMORY       = 18
-    GT_MONTANA      = 19
+    GT_FREECELL = 10
+    GT_GOLF = 11
+    GT_GYPSY = 12
+    GT_HANAFUDA = 13
+    GT_HEXADECK = 14
+    GT_KLONDIKE = 15
+    GT_MAHJONGG = 16
+    GT_MATRIX = 17
+    GT_MEMORY = 18
+    GT_MONTANA = 19
     GT_MUGHAL_GANJIFA = 20
-    GT_NAPOLEON     = 21
+    GT_NAPOLEON = 21
     GT_NAVAGRAHA_GANJIFA = 22
-    GT_NUMERICA     = 23
+    GT_NUMERICA = 23
     GT_PAIRING_TYPE = 24
-    GT_POKER_TYPE   = 25
-    GT_PUZZLE_TYPE  = 26
-    GT_RAGLAN       = 27
-    GT_ROW_TYPE     = 28
-    GT_SIMPLE_TYPE  = 29
-    GT_SPIDER       = 30
-    GT_TAROCK       = 31
-    GT_TERRACE      = 32
-    GT_YUKON        = 33
-    GT_SHISEN_SHO   = 34
-    GT_CUSTOM       = 40
+    GT_POKER_TYPE = 25
+    GT_PUZZLE_TYPE = 26
+    GT_RAGLAN = 27
+    GT_ROW_TYPE = 28
+    GT_SIMPLE_TYPE = 29
+    GT_SPIDER = 30
+    GT_TAROCK = 31
+    GT_TERRACE = 32
+    GT_YUKON = 33
+    GT_SHISEN_SHO = 34
+    GT_HANOI = 35
+    GT_PEGGED = 36
+    GT_CRIBBAGE_TYPE = 37
+    GT_CUSTOM = 40
     # extra flags
-    GT_BETA          = 1 << 12      # beta version of game driver
-    GT_CHILDREN      = 1 << 13      # *not used*
-    GT_CONTRIB       = 1 << 14      # contributed games under the GNU GPL
-    GT_HIDDEN        = 1 << 15      # not visible in menus, but games can be loaded
-    GT_OPEN          = 1 << 16
-    GT_ORIGINAL      = 1 << 17
-    GT_POPULAR       = 1 << 18      # *not used*
-    GT_RELAXED       = 1 << 19
-    GT_SCORE         = 1 << 20      # game has some type of scoring
+    GT_BETA = 1 << 12      # beta version of game driver
+    GT_CHILDREN = 1 << 13      # *not used*
+    GT_CONTRIB = 1 << 14      # contributed games under the GNU GPL
+    GT_HIDDEN = 1 << 15      # not visible in menus, but games can be loaded
+    GT_OPEN = 1 << 16
+    GT_ORIGINAL = 1 << 17
+    GT_POPULAR = 1 << 18      # *not used*
+    GT_RELAXED = 1 << 19
+    GT_SCORE = 1 << 20      # game has some type of scoring
     GT_SEPARATE_DECKS = 1 << 21
-    GT_XORIGINAL     = 1 << 22      # original games by other people, not playable
+    GT_XORIGINAL = 1 << 22      # original games by other people, not playable
     # skill level
-    SL_LUCK         = 1
-    SL_MOSTLY_LUCK  = 2
-    SL_BALANCED     = 3
+    SL_LUCK = 1
+    SL_MOSTLY_LUCK = 2
+    SL_BALANCED = 3
     SL_MOSTLY_SKILL = 4
-    SL_SKILL        = 5
+    SL_SKILL = 5
     #
     TYPE_NAMES = {
         GT_BAKERS_DOZEN:        n_("Baker's Dozen"),
@@ -127,77 +131,134 @@ class GI:
         GT_2DECK_TYPE:          n_("Two-Deck games"),
         GT_3DECK_TYPE:          n_("Three-Deck games"),
         GT_4DECK_TYPE:          n_("Four-Deck games"),
+
+        GT_MAHJONGG:            n_("Mahjongg"),
+        GT_HANAFUDA:            n_("Hanafuda"),
+        GT_MUGHAL_GANJIFA:      n_("Mughal Ganjifa"),
+        GT_DASHAVATARA_GANJIFA: n_("Dashavatara Ganjifa"),
+
+        GT_CRIBBAGE_TYPE:       n_("Cribbage"),
+        GT_HEXADECK:            n_("Hex A Deck"),
+        GT_MATRIX:              n_("Matrix"),
+        GT_MEMORY:              n_("Memory"),
+        GT_PEGGED:              n_("Pegged"),
+        GT_POKER_TYPE:          n_("Poker"),
+        GT_SHISEN_SHO:          n_("Shisen-Sho"),
+        GT_TAROCK:              n_("Tarock"),
+        GT_HANOI:               n_("Tower of Hanoi"),
+
+        GT_CUSTOM:              n_("Custom"),
     }
 
-##     SELECT_GAME_BY_TYPE = []
-##     for gt, name in TYPE_NAMES.items():
-##         if not name.endswith('games'):
-##             name = name+n_(' type')
-##         SELECT_GAME_BY_TYPE.append(
-##             (name, lambda gi, gt=gt: gi.si.game_type == gt))
-##     SELECT_GAME_BY_TYPE = tuple(SELECT_GAME_BY_TYPE)
+    #      SELECT_GAME_BY_TYPE = []
+    #      for gt, name in TYPE_NAMES.items():
+    #          if not name.endswith('games'):
+    #              name = name+n_(' type')
+    #          SELECT_GAME_BY_TYPE.append(
+    #              (name, lambda gi, gt=gt: gi.si.game_type == gt))
+    #      SELECT_GAME_BY_TYPE = tuple(SELECT_GAME_BY_TYPE)
+
+    def _gen_select(title, game_type):
+        def _callback(gi, gt=game_type):
+            return gi.si.game_type == gt
+        return (title, _callback)
 
     SELECT_GAME_BY_TYPE = (
-        (n_("Baker's Dozen type"),lambda gi, gt=GT_BAKERS_DOZEN: gi.si.game_type == gt),
-        (n_("Beleaguered Castle type"),lambda gi, gt=GT_BELEAGUERED_CASTLE: gi.si.game_type == gt),
-        (n_("Canfield type"), lambda gi, gt=GT_CANFIELD: gi.si.game_type == gt),
-        (n_("Fan type"),      lambda gi, gt=GT_FAN_TYPE: gi.si.game_type == gt),
-        (n_("Forty Thieves type"),lambda gi, gt=GT_FORTY_THIEVES: gi.si.game_type == gt),
-        (n_("FreeCell type"), lambda gi, gt=GT_FREECELL: gi.si.game_type == gt),
-        (n_("Golf type"),     lambda gi, gt=GT_GOLF: gi.si.game_type == gt),
-        (n_("Gypsy type"),    lambda gi, gt=GT_GYPSY: gi.si.game_type == gt),
-        (n_("Klondike type"), lambda gi, gt=GT_KLONDIKE: gi.si.game_type == gt),
-        (n_("Montana type"),  lambda gi, gt=GT_MONTANA: gi.si.game_type == gt),
-        (n_("Napoleon type"), lambda gi, gt=GT_NAPOLEON: gi.si.game_type == gt),
-        (n_("Numerica type"), lambda gi, gt=GT_NUMERICA: gi.si.game_type == gt),
-        (n_("Pairing type"),  lambda gi, gt=GT_PAIRING_TYPE: gi.si.game_type == gt),
-        (n_("Raglan type"),   lambda gi, gt=GT_RAGLAN: gi.si.game_type == gt),
-        (n_("Simple games"),  lambda gi, gt=GT_SIMPLE_TYPE: gi.si.game_type == gt),
-        (n_("Spider type"),   lambda gi, gt=GT_SPIDER: gi.si.game_type == gt),
-        (n_("Terrace type"),  lambda gi, gt=GT_TERRACE: gi.si.game_type == gt),
-        (n_("Yukon type"),    lambda gi, gt=GT_YUKON: gi.si.game_type == gt),
-        (n_("One-Deck games"),lambda gi, gt=GT_1DECK_TYPE: gi.si.game_type == gt),
-        (n_("Two-Deck games"),lambda gi, gt=GT_2DECK_TYPE: gi.si.game_type == gt),
-        (n_("Three-Deck games"),lambda gi, gt=GT_3DECK_TYPE: gi.si.game_type == gt),
-        (n_("Four-Deck games"),lambda gi, gt=GT_4DECK_TYPE: gi.si.game_type == gt),
+        _gen_select(title=n_("Baker's Dozen type"), game_type=GT_BAKERS_DOZEN),
+        _gen_select(
+            title=n_("Beleaguered Castle type"),
+            game_type=GT_BELEAGUERED_CASTLE),
+        _gen_select(title=n_("Canfield type"), game_type=GT_CANFIELD),
+        _gen_select(title=n_("Fan type"), game_type=GT_FAN_TYPE),
+        _gen_select(
+            title=n_("Forty Thieves type"), game_type=GT_FORTY_THIEVES),
+        _gen_select(title=n_("FreeCell type"), game_type=GT_FREECELL),
+        _gen_select(title=n_("Golf type"), game_type=GT_GOLF),
+        _gen_select(title=n_("Gypsy type"), game_type=GT_GYPSY),
+        _gen_select(title=n_("Klondike type"), game_type=GT_KLONDIKE),
+        _gen_select(title=n_("Montana type"), game_type=GT_MONTANA),
+        _gen_select(title=n_("Napoleon type"), game_type=GT_NAPOLEON),
+        _gen_select(title=n_("Numerica type"), game_type=GT_NUMERICA),
+        _gen_select(title=n_("Pairing type"), game_type=GT_PAIRING_TYPE),
+        _gen_select(title=n_("Raglan type"), game_type=GT_RAGLAN),
+        _gen_select(title=n_("Simple games"), game_type=GT_SIMPLE_TYPE),
+        _gen_select(title=n_("Spider type"), game_type=GT_SPIDER),
+        _gen_select(title=n_("Terrace type"), game_type=GT_TERRACE),
+        _gen_select(title=n_("Yukon type"), game_type=GT_YUKON),
+        _gen_select(title=n_("One-Deck games"), game_type=GT_1DECK_TYPE),
+        _gen_select(title=n_("Two-Deck games"), game_type=GT_2DECK_TYPE),
+        _gen_select(title=n_("Three-Deck games"), game_type=GT_3DECK_TYPE),
+        _gen_select(title=n_("Four-Deck games"), game_type=GT_4DECK_TYPE),
     )
 
     SELECT_ORIGINAL_GAME_BY_TYPE = (
-        (n_("French type"),         lambda gi, gf=GT_ORIGINAL, gt=(GT_HANAFUDA, GT_HEXADECK, GT_MUGHAL_GANJIFA, GT_NAVAGRAHA_GANJIFA, GT_DASHAVATARA_GANJIFA, GT_TAROCK,): gi.si.game_flags & gf and gi.si.game_type not in gt),
-        (n_("Ganjifa type"),        lambda gi, gf=GT_ORIGINAL, gt=(GT_MUGHAL_GANJIFA, GT_NAVAGRAHA_GANJIFA, GT_DASHAVATARA_GANJIFA,): gi.si.game_flags & gf and gi.si.game_type in gt),
-        (n_("Hanafuda type"),       lambda gi, gf=GT_ORIGINAL, gt=GT_HANAFUDA: gi.si.game_flags & gf and gi.si.game_type == gt),
-        (n_("Hex A Deck type"),     lambda gi, gf=GT_ORIGINAL, gt=GT_HEXADECK: gi.si.game_flags & gf and gi.si.game_type == gt),
-        (n_("Tarock type"),         lambda gi, gf=GT_ORIGINAL, gt=GT_TAROCK: gi.si.game_flags & gf and gi.si.game_type == gt),
+        (n_("French type"), lambda gi, gf=GT_ORIGINAL,
+            gt=(
+                GT_HANAFUDA,
+                GT_HEXADECK, GT_MUGHAL_GANJIFA, GT_NAVAGRAHA_GANJIFA,
+                GT_DASHAVATARA_GANJIFA, GT_TAROCK,): gi.si.game_flags & gf and
+            gi.si.game_type not in gt),
+        (n_("Ganjifa type"), lambda gi, gf=GT_ORIGINAL,
+            gt=(GT_MUGHAL_GANJIFA, GT_NAVAGRAHA_GANJIFA,
+                GT_DASHAVATARA_GANJIFA,): gi.si.game_flags & gf and
+            gi.si.game_type in gt),
+        (n_("Hanafuda type"), lambda gi, gf=GT_ORIGINAL, gt=GT_HANAFUDA:
+            gi.si.game_flags & gf and gi.si.game_type == gt),
+        (n_("Hex A Deck type"), lambda gi, gf=GT_ORIGINAL, gt=GT_HEXADECK:
+            gi.si.game_flags & gf and gi.si.game_type == gt),
+        (n_("Tarock type"), lambda gi, gf=GT_ORIGINAL, gt=GT_TAROCK:
+            gi.si.game_flags & gf and gi.si.game_type == gt),
     )
 
     SELECT_CONTRIB_GAME_BY_TYPE = (
-        (n_("French type"),         lambda gi, gf=GT_CONTRIB, gt=(GT_HANAFUDA, GT_HEXADECK, GT_MUGHAL_GANJIFA, GT_NAVAGRAHA_GANJIFA, GT_DASHAVATARA_GANJIFA, GT_TAROCK,): gi.si.game_flags & gf and gi.si.game_type not in gt),
-        (n_("Ganjifa type"),        lambda gi, gf=GT_CONTRIB, gt=(GT_MUGHAL_GANJIFA, GT_NAVAGRAHA_GANJIFA, GT_DASHAVATARA_GANJIFA,): gi.si.game_flags & gf and gi.si.game_type in gt),
-        (n_("Hanafuda type"),       lambda gi, gf=GT_CONTRIB, gt=GT_HANAFUDA: gi.si.game_flags & gf and gi.si.game_type == gt),
-        (n_("Hex A Deck type"),     lambda gi, gf=GT_CONTRIB, gt=GT_HEXADECK: gi.si.game_flags & gf and gi.si.game_type == gt),
-        (n_("Tarock type"),         lambda gi, gf=GT_CONTRIB, gt=GT_TAROCK: gi.si.game_flags & gf and gi.si.game_type == gt),
+        (n_("French type"), lambda gi, gf=GT_CONTRIB,
+            gt=(GT_HANAFUDA, GT_HEXADECK, GT_MUGHAL_GANJIFA,
+                GT_NAVAGRAHA_GANJIFA, GT_DASHAVATARA_GANJIFA, GT_TAROCK,):
+            gi.si.game_flags & gf and gi.si.game_type not in gt),
+        (n_("Ganjifa type"), lambda gi, gf=GT_CONTRIB,
+            gt=(GT_MUGHAL_GANJIFA, GT_NAVAGRAHA_GANJIFA,
+                GT_DASHAVATARA_GANJIFA,):
+            gi.si.game_flags & gf and gi.si.game_type in gt),
+        (n_("Hanafuda type"), lambda gi, gf=GT_CONTRIB, gt=GT_HANAFUDA:
+            gi.si.game_flags & gf and gi.si.game_type == gt),
+        (n_("Hex A Deck type"), lambda gi, gf=GT_CONTRIB, gt=GT_HEXADECK:
+            gi.si.game_flags & gf and gi.si.game_type == gt),
+        (n_("Tarock type"), lambda gi, gf=GT_CONTRIB, gt=GT_TAROCK:
+            gi.si.game_flags & gf and gi.si.game_type == gt),
     )
 
     SELECT_ORIENTAL_GAME_BY_TYPE = (
-        (n_("Dashavatara Ganjifa type"), lambda gi, gt=GT_DASHAVATARA_GANJIFA: gi.si.game_type == gt),
-        (n_("Ganjifa type"),        lambda gi, gt=(GT_MUGHAL_GANJIFA, GT_NAVAGRAHA_GANJIFA, GT_DASHAVATARA_GANJIFA,): gi.si.game_type in gt),
-        (n_("Hanafuda type"),       lambda gi, gt=GT_HANAFUDA: gi.si.game_type == gt),
-        (n_("Mughal Ganjifa type"), lambda gi, gt=GT_MUGHAL_GANJIFA: gi.si.game_type == gt),
-        (n_("Navagraha Ganjifa type"), lambda gi, gt=GT_NAVAGRAHA_GANJIFA: gi.si.game_type == gt),
+        (n_("Dashavatara Ganjifa type"), lambda gi, gt=GT_DASHAVATARA_GANJIFA:
+            gi.si.game_type == gt),
+        (n_("Ganjifa type"), lambda gi,
+            gt=(GT_MUGHAL_GANJIFA, GT_NAVAGRAHA_GANJIFA,
+                GT_DASHAVATARA_GANJIFA,): gi.si.game_type in gt),
+        (n_("Hanafuda type"),
+            lambda gi, gt=GT_HANAFUDA: gi.si.game_type == gt),
+        (n_("Mughal Ganjifa type"),
+            lambda gi, gt=GT_MUGHAL_GANJIFA: gi.si.game_type == gt),
+        (n_("Navagraha Ganjifa type"),
+            lambda gi, gt=GT_NAVAGRAHA_GANJIFA: gi.si.game_type == gt),
     )
 
     SELECT_SPECIAL_GAME_BY_TYPE = (
-        (n_("Shisen-Sho"),      lambda gi, gt=GT_SHISEN_SHO: gi.si.game_type == gt),
-        (n_("Hex A Deck type"), lambda gi, gt=GT_HEXADECK: gi.si.game_type == gt),
-        (n_("Matrix type"),     lambda gi, gt=GT_MATRIX: gi.si.game_type == gt),
-        (n_("Memory type"),     lambda gi, gt=GT_MEMORY: gi.si.game_type == gt),
-        (n_("Poker type"),      lambda gi, gt=GT_POKER_TYPE: gi.si.game_type == gt),
-        (n_("Puzzle type"),     lambda gi, gt=GT_PUZZLE_TYPE: gi.si.game_type == gt),
-        (n_("Tarock type"),     lambda gi, gt=GT_TAROCK: gi.si.game_type == gt),
+        (n_("Cribbage type"),
+            lambda gi, gt=GT_CRIBBAGE_TYPE: gi.si.game_type == gt),
+        (n_("Hex A Deck type"),
+            lambda gi, gt=GT_HEXADECK: gi.si.game_type == gt),
+        (n_("Matrix type"), lambda gi, gt=GT_MATRIX: gi.si.game_type == gt),
+        (n_("Memory type"), lambda gi, gt=GT_MEMORY: gi.si.game_type == gt),
+        (n_("Pegged type"), lambda gi, gt=GT_PEGGED: gi.si.game_type == gt),
+        (n_("Poker type"), lambda gi, gt=GT_POKER_TYPE: gi.si.game_type == gt),
+        (n_("Puzzle type"),
+            lambda gi, gt=GT_PUZZLE_TYPE: gi.si.game_type == gt),
+        (n_("Shisen-Sho type"),
+            lambda gi, gt=GT_SHISEN_SHO: gi.si.game_type == gt),
+        (n_("Tarock type"), lambda gi, gt=GT_TAROCK: gi.si.game_type == gt),
+        (n_("Tower of Hanoi type"),
+            lambda gi, gt=GT_HANOI: gi.si.game_type == gt),
     )
 
-
-
     # These obsolete gameids have been used in previous versions of
     # PySol and are no longer supported because of internal changes
     # (mainly rule changes). The game has been assigned a new id.
@@ -208,54 +269,109 @@ class GI:
          72:  115,              # Little Forty
          75:  126,              # Red and Black
          82:  901,              # La Belle Lucie (Midnight Oil)
-##        155: 5034,              # Mahjongg - Flying Dragon
-##        156: 5035,              # Mahjongg - Fortress Towers
-        262:  105,              # Canfield
-        902:   88,              # Trefoil
-        904:   68,              # Lexington Harp
-        297:  631,              # Alternation/Alternations
+         # 155: 5034,              # Mahjongg - Flying Dragon
+         # 156: 5035,              # Mahjongg - Fortress Towers
+         262:  105,              # Canfield
+         902:   88,              # Trefoil
+         904:   68,              # Lexington Harp
+         297:  631,              # Alternation/Alternations
     }
 
+    # For games by compatibility, note that missing games may actually
+    # be present under alternate names.  This needs to be verified.
+    # If such a game is found, the alternate name should be added if
+    # possible, and the game recorded in the compatibility section
+    # appropriately.
+    #
+    # Note that there are instances where another program's
+    # implementation of a game uses different rules than PySol, or
+    # has a different game with the same name.  These are marked
+    # as missing.
+    #
+    # If a game is listed as missing from multiple collections below,
+    # adding it should be a priority.
+
     GAMES_BY_COMPATIBILITY = (
         # Atari ST Patience game v2.13 (we have 10 out of 10 games)
         ("Atari ST Patience", (1, 3, 4, 7, 12, 14, 15, 16, 17, 39,)),
 
-        ## Gnome AisleRiot 1.0.51 (we have 28 out of 32 games)
-        ##   still missing: Camelot, Clock, Thieves, Thirteen
-        ##("Gnome AisleRiot 1.0.51", (
-        ##    2, 8, 11, 19, 27, 29, 33, 34, 35, 40,
-        ##    41, 42, 43, 58, 59, 92, 93, 94, 95, 96,
-        ##    100, 105, 111, 112, 113, 130, 200, 201,
-        ##)),
-        ## Gnome AisleRiot 1.4.0.1 (we have XX out of XX games)
-        ##("Gnome AisleRiot", (
-        ##    1, 2, 8, 11, 19, 27, 29, 33, 34, 35, 40,
-        ##    41, 42, 43, 58, 59, 92, 93, 94, 95, 96,
-        ##    100, 105, 111, 112, 113, 130, 200, 201,
-        ##)),
-        # Gnome AisleRiot 2.2.0 (we have 61 out of 70 games)
+        #  Gnome AisleRiot 1.0.51 (we have 28 out of 32 games)
+        #    still missing: Camelot, Clock, Thieves, Thirteen
+        # ("Gnome AisleRiot 1.0.51", (
+        #     2, 8, 11, 19, 27, 29, 33, 34, 35, 40,
+        #     41, 42, 43, 58, 59, 92, 93, 94, 95, 96,
+        #     100, 105, 111, 112, 113, 130, 200, 201,
+        # )),
+        #  Gnome AisleRiot 1.4.0.1 (we have XX out of XX games)
+        # ("Gnome AisleRiot", (
+        #     1, 2, 8, 11, 19, 27, 29, 33, 34, 35, 40,
+        #     41, 42, 43, 58, 59, 92, 93, 94, 95, 96,
+        #     100, 105, 111, 112, 113, 130, 200, 201,
+        # )),
+        # Gnome AisleRiot 2.2.0 (we have 65 out of 70 games)
+        # Gnome AisleRiot 3.22.7
         #   still missing:
-        #         Gay gordons, Helsinki,
-        #         Isabel, Labyrinth, Quatorze, Thieves,
-        #         Treize, Valentine, Yeld.
+        #       Block Ten, Hamilton, Isabel, King's Audience, Labyrinth,
+        #       Napoleon's Tomb, Saratoga, Thieves, Treize, Valentine,
+        #       Wall
         ("Gnome AisleRiot", (
-            1, 2, 8, 9, 11, 12, 19, 24, 27, 29, 31, 33, 34, 35, 36, 40,
-            41, 42, 43, 45, 48, 58, 59, 67, 89, 91, 92, 93, 94, 95, 96,
-            100, 105, 111, 112, 113, 130, 139, 144, 146, 147, 148, 200,
-            201, 206, 224, 225, 229, 230, 233, 257, 258, 280, 281, 282,
-            283, 284, 551, 552, 553, 737,
+            1, 2, 8, 9, 11, 12, 13, 19, 24, 27, 29, 31, 33, 34, 35, 36,
+            38, 40, 41, 42, 43, 45, 48, 58, 59, 60, 65, 67, 89, 91, 92,
+            93, 94, 95, 96, 97, 100, 104, 105, 111, 112, 113, 130, 135,
+            139, 144, 146, 147, 148, 200, 201, 206, 224, 225, 229, 230,
+            233, 257, 258, 280, 281, 282, 283, 284, 334, 384, 495, 551,
+            552, 553, 572, 593, 674, 700, 737, 772, 810, 819, 824, 22231,
         )),
 
-        ## KDE Patience 0.7.3 from KDE 1.1.2 (we have 6 out of 9 games)
-        ##("KDE Patience 0.7.3", (2, 7, 8, 18, 256, 903,)),
-        ## KDE Patience 2.0 from KDE 2.1.2 (we have 11 out of 13 games)
-        ##("KDE Patience", (1, 2, 7, 8, 18, 19, 23, 50, 256, 261, 903,)),
-        ## KDE Patience 2.0 from KDE 2.2beta1 (we have 12 out of 14 games)
-        ##("KDE Patience", (1, 2, 7, 8, 18, 19, 23, 36, 50, 256, 261, 903,)),
+        #  KDE Patience 0.7.3 from KDE 1.1.2 (we have 6 out of 9 games)
+        # ("KDE Patience 0.7.3", (2, 7, 8, 18, 256, 903,)),
+        #  KDE Patience 2.0 from KDE 2.1.2 (we have 11 out of 13 games)
+        # ("KDE Patience", (1, 2, 7, 8, 18, 19, 23, 50, 256, 261, 903,)),
+        #  KDE Patience 2.0 from KDE 2.2beta1 (we have 12 out of 14 games)
+        # ("KDE Patience", (1, 2, 7, 8, 18, 19, 23, 36, 50, 256, 261, 903,)),
         # KDE Patience 2.0 from KDE 3.1.1 (we have 15 out of 15 games)
         ("KDE Patience", (1, 2, 7, 8, 18, 19, 23, 36, 50,
                           256, 261, 277, 278, 279, 903,)),
 
+        # Microsoft Solitaire (we have all 5 games)
+        ("Microsoft Solitaire Collection", (2, 8, 11, 38, 22231,)),
+
+        # XM Solitaire
+        # still missing:
+        #       Ace of Hearts, Affinity, Agnes Three, Antares, Archway,
+        #       Avenue, Baker's Fan, Baker's Spider, Bedeviled, Binding,
+        #       Black Holes, Black Spider, Block Ten, California,
+        #       Carcassone, Cascade, Club, Color Cell, Cornelius,
+        #       Demons and Thieves, Desert Fox, Deuces and Queens,
+        #       Double Antares, Double Antarctica, Double Arctica,
+        #       Double Baker's Spider, Double Cascade, Double Fourteens,
+        #       Double Line 8, Double Majesty, Double Sea Towers,
+        #       Double Spidercells, Doublet Cell 5, Doubt, Dream Fan,
+        #       Dumfries Cell, Falcon Wing, Fan Nine, Fanny 6,
+        #       Four By Ten, FreeCell AK, Gaps Alter, Gaps Diff,
+        #       George V, Grandmother's Clock, In a Frame, Inverted FreeCell,
+        #       Kings, Klondike FreeCell, La Cabane, La Double Entente,
+        #       Little Gazette, Magic FreeCell, Mini Gaps, Montreal,
+        #       Napoleon at Iena, Napoleon at Waterloo, Napoleon's Guards,
+        #       Nationale, Oasis, Opera, Ordered Suits, Osmotic FreeCell,
+        #       Pair FreeCell, Pairs 2, Petal, Rainbow Fan, Reserved Thirteens,
+        #       Sea Spider, Sept Piles 0, Short Solitaire, Simple Alternations,
+        #       Simple Spark, Step By Step, Strategy 7, Stripped FreeCell,
+        #       Tarantula, Triple Dispute, Trusty Twenty, Two Ways 3,
+        #       Up Or Down, Versailles, Vertical FreeCell, Wasp Baby,
+        #       Yukon FreeCell
+        ("XM Solitaire", (
+            2, 8, 9, 13, 15, 18, 19, 20, 29, 30, 31, 34, 36, 38, 41, 42,
+            45, 46, 50, 53, 54, 56, 57, 59, 64, 77, 78, 86, 96, 97, 98,
+            105, 110, 112, 124, 145, 220, 222, 223, 224, 228, 231, 233,
+            234, 235, 236, 257, 258, 264, 265, 267, 270, 271, 290, 291,
+            292, 303, 309, 314, 318, 320, 322, 324, 325, 336, 338, 341,
+            363, 364, 372, 376, 383, 384, 385, 386, 390, 391, 393, 398,
+            405, 415, 416, 425, 451, 453, 461, 464, 466, 467, 476, 480,
+            484, 511, 512, 516, 561, 610, 625, 629, 631, 638, 641, 647,
+            650, 655, 678, 734, 751, 784, 825, 901,
+        )),
+
         # xpat2 1.06 (we have 14 out of 16 games)
         #   still missing: Michael's Fantasy, modCanfield
         ("xpat2", (
@@ -267,24 +383,28 @@ class GI:
         ("Paul Alfille", (8,)),
         ("C.L. Baker", (45,)),
         ("David Bernazzani", (314,)),
-        ("Gordon Bower", (763,)),
+        ("Gordon Bower", (763, 783,)),
         ("Art Cabral", (9,)),
+        ("Richard A. Canfield", (105,)),
         ("Robert Harbin", (381,)),
-        ("Robert Hogue", (22216,)),
+        ("Robert Hogue", (22216, 22217, 22218, 22231,)),
         ("Charles Jewell", (220, 309,)),
         ("Michael Keller", (592,)),
         ("Fred Lunde", (459,)),
         ("Albert Morehead and Geoffrey Mott-Smith", (25, 42, 48, 173, 282,
                                                      303, 362, 547, 738)),
-        ("David Parlett", (64, 98, 294, 338, 654, 674,)),
+        ("Toby Ord", (788,)),
+        ("David Parlett", (64, 98, 294, 338, 654, 796, 812)),
         ("Randy Rasa", (187, 190, 191, 192,)),
-        ("Captain Jeffrey T. Spaulding", (400,)),
         ("Adam Selene", (366,)),
+        ("Jim Sizelove", (555001,)),
+        ("Captain Jeffrey T. Spaulding", (400,)),
         ("John Stoneham", (201,)),
         ("Bryan Stout", (655,)),
         ("Bill Taylor", (349,)),
         ("Thomas Warfield", (189, 264, 300, 320, 336, 337, 359,
-                             415, 427, 458, 495, 496, 497, 508,)),
+                             415, 427, 458, 495, 496, 497, 508,
+                             800, 814, 820, 825,)),
         )
 
     GAMES_BY_PYSOL_VERSION = (
@@ -302,9 +422,9 @@ class GI:
         ("2.99", (37,)),
         ("3.00", (38, 39,
                   40, 41, 42, 43,     45, 46, 47, 48, 49,
-                  50, 51,903, 53, 54, 55, 56, 57, 58, 59,
+                  50, 51, 903, 53, 54, 55, 56, 57, 58, 59,
                   60, 61, 62, 63, 64, 65, 66, 67, 68, 69,
-                  70, 71,115, 73, 74,126, 76, 77, 78, 79,
+                  70, 71, 115, 73, 74, 126, 76, 77, 78, 79,
                   80, 81,     83, 84, 85, 86, 87, 88, 89,
                   90, 91, 92, 93, 94, 95, 96, 97, 98, 99,
                   100, 101, 102, 103, 104, 107, 108,)),
@@ -316,7 +436,7 @@ class GI:
         ("3.21", (143, 144)),
         ("3.30", (145, 146, 147, 148, 149, 150, 151)),
         ("3.40", (152, 153, 154)),
-        ("4.00", (          157, 158, 159, 160, 161, 162, 163, 164)),
+        ("4.00", (157, 158, 159, 160, 161, 162, 163, 164)),
         ("4.20", (165, 166, 167, 168, 169, 170, 171, 172, 173, 174,
                   175, 176, 177, 178)),
         ("4.30", (179, 180, 181, 182, 183, 184)),
@@ -328,8 +448,8 @@ class GI:
                   220, 221, 222, 223, 224, 225, 226, 227, 228, 229,
                   230, 231, 232, 233, 234, 235, 236)),
         ("4.70", (237,)),
-        ('fc-0.5.0', ( # moved from Ultrasol
-                      #121, 122, 187, 188, 189, 190, 191, 192, 194, 197, 198,
+        ('fc-0.5.0', (  # moved from Ultrasol
+                      # 121, 122, 187, 188, 189, 190, 191, 192, 194, 197, 198,
                       5301, 5302, 9011, 11001, 11002, 11003, 11004, 11005,
                       11006, 12353, 12354, 12355, 12356, 12357, 12358, 12359,
                       12360, 12361, 12362, 12363, 12364, 12365, 12366, 12367,
@@ -346,7 +466,7 @@ class GI:
                       16674, 16675, 16676, 16677, 16678, 16679, 16680, 22216,
                       22223, 22224, 22225, 22226, 22227, 22228, 22229, 22230,
                       22231, 22232,)),
-        ('fc-0.8.0', tuple(range(263, 323))), # exclude 297
+        ('fc-0.8.0', tuple(range(263, 323))),  # exclude 297
         ('fc-0.9.0', tuple(range(323, 421))),
         ('fc-0.9.1', tuple(range(421, 441))),
         ('fc-0.9.2', tuple(range(441, 466))),
@@ -354,12 +474,17 @@ class GI:
         ('fc-0.9.4', tuple(range(661, 671))),
         ('fc-1.0',   tuple(range(671, 711))),
         ('fc-1.1',   tuple(range(711, 759))),
-        ('fc-2.0',   tuple(range(11011, 11014)) + tuple(range(759, 767)) ),
+        ('fc-2.0',   tuple(range(11011, 11014)) + tuple(range(759, 767))),
+        ('fc-2.1',   tuple(range(767, 774)) + (555001,)),
+        ('fc-2.8',   (343001,)),
+        ('fc-2.12',   tuple(range(774, 811)) + (16681,) +
+         tuple(range(22217, 22219))),
+        ('fc-2.14', tuple(range(811, 827)))
     )
 
     # deprecated - the correct way is to or a GI.GT_XXX flag
     # in the registerGame() call
-    _CHILDREN_GAMES = [16, 33, 55, 90, 91, 96, 97, 176, 903,]
+    _CHILDREN_GAMES = [16, 33, 55, 90, 91, 96, 97, 176, 903, ]
 
     _OPEN_GAMES = []
 
@@ -383,7 +508,7 @@ class GI:
         903,   # Ace Up
         5034,  # Mahjongg Flying Dragon
         5401,  # Mahjongg Taipei
-        12345, # Oonsoo
+        12345,  # Oonsoo
     ]
 
 
@@ -402,36 +527,36 @@ class GameInfo(Struct):
                  # keyword arguments:
                  si={}, category=0,
                  short_name=None, altnames=(),
-                 suits=range(4), ranks=range(13), trumps=(),
+                 suits=list(range(4)), ranks=list(range(13)), trumps=(),
                  rules_filename=None,
                  ):
         #
         def to_unicode(s):
-            if isinstance(s, unicode):
+            if isinstance(s, six.text_type):
                 return s
             try:
-                s = unicode(s, 'utf-8')
-            except UnicodeDecodeError, err:
+                s = six.text_type(s, 'utf-8')
+            except UnicodeDecodeError as err:
                 print_err(err)
-                s = unicode(s, 'utf-8', 'ignore')
+                s = six.text_type(s, 'utf-8', 'ignore')
             return s
         ncards = decks * (len(suits) * len(ranks) + len(trumps))
         game_flags = game_type & ~1023
         game_type = game_type & 1023
         name = to_unicode(name)
         en_name = name                  # for app.getGameRulesFilename
-        if settings.TRANSLATE_GAME_NAMES:
+        if pysollib.settings.TRANSLATE_GAME_NAMES:
             name = _(name)
         if not short_name:
             short_name = name
         else:
             short_name = to_unicode(short_name)
-            if settings.TRANSLATE_GAME_NAMES:
+            if pysollib.settings.TRANSLATE_GAME_NAMES:
                 short_name = _(short_name)
-        if isinstance(altnames, basestring):
+        if isinstance(altnames, six.string_types):
             altnames = (altnames,)
         altnames = [to_unicode(n) for n in altnames]
-        if settings.TRANSLATE_GAME_NAMES:
+        if pysollib.settings.TRANSLATE_GAME_NAMES:
             altnames = [_(n) for n in altnames]
         #
         if not (1 <= category <= 9):
@@ -455,11 +580,13 @@ class GameInfo(Struct):
         if not (1 <= id <= 999999):
             raise GameInfoException(name+": invalid game ID "+str(id))
         if category == GI.GC_MAHJONGG:
-            if decks%4:
-                raise GameInfoException(name+": invalid number of decks "+str(id))
+            if decks % 4:
+                raise GameInfoException(name+": invalid number of decks " +
+                                        str(id))
         else:
             if not (1 <= decks <= 4):
-                raise GameInfoException(name+": invalid number of decks "+str(id))
+                raise GameInfoException(
+                    name+": invalid number of decks "+str(id))
         if not name:
             raise GameInfoException(name+": invalid game name")
         if GI.PROTECTED_GAMES.get(id):
@@ -520,7 +647,7 @@ class GameManager:
         return self.__all_games.get(key)
 
     def _check_game(self, gi):
-        ##print 'check game:', gi.id, gi.short_name.encode('utf-8')
+        # print 'check game:', gi.id, gi.short_name.encode('utf-8')
         if gi.id in self.__all_games:
             raise GameInfoException("duplicate game ID %s: %s and %s" %
                                     (gi.id, str(gi.gameclass),
@@ -542,14 +669,14 @@ class GameManager:
                                         (gi.id, n))
 
     def register(self, gi):
-        ##print gi.id, gi.short_name.encode('utf-8')
+        # print gi.id, gi.short_name.encode('utf-8')
         if not isinstance(gi, GameInfo):
             raise GameInfoException("wrong GameInfo class")
-        if self.check_game and settings.CHECK_GAMES:
+        if self.check_game and pysollib.settings.CHECK_GAMES:
             self._check_game(gi)
-        ##if 0 and gi.si.game_flags & GI.GT_XORIGINAL:
-        ##    return
-        ##print gi.id, gi.name
+        # if 0 and gi.si.game_flags & GI.GT_XORIGINAL:
+        #     return
+        # print gi.id, gi.name
         self.__all_games[gi.id] = gi
         self.__all_gamenames[gi.name] = gi
         for n in gi.altnames:
@@ -564,12 +691,13 @@ class GameManager:
             self.__games_by_name = None
             # update registry
             k = gi.si.game_type
-            self.registered_game_types[k] = self.registered_game_types.get(k, 0) + 1
-##             if not gi.si.game_type == GI.GT_MAHJONGG:
-##                 for v, k in GI.GAMES_BY_PYSOL_VERSION:
-##                     if gi.id in k: break
-##                 else:
-##                     print gi.id
+            self.registered_game_types[k] = \
+                self.registered_game_types.get(k, 0) + 1
+#              if not gi.si.game_type == GI.GT_MAHJONGG:
+#                  for v, k in GI.GAMES_BY_PYSOL_VERSION:
+#                      if gi.id in k: break
+#                  else:
+#                      print gi.id
             if hasattr(gi.gameclass, 'Solver_Class') and \
                gi.gameclass.Solver_Class is not None:
                 self.__games_for_solver.append(gi.id)
@@ -585,27 +713,27 @@ class GameManager:
     #
 
     def getAllGames(self):
-        ##return self.__all_games
-        return self.__games.values()
+        # return self.__all_games
+        return list(self.__games.values())
 
     def getGamesIdSortedById(self):
         if self.__games_by_id is None:
-            l = self.__games.keys()
-            l.sort()
-            self.__games_by_id = tuple(l)
+            lst = list(self.__games.keys())
+            lst.sort()
+            self.__games_by_id = tuple(lst)
         return self.__games_by_id
 
     def getGamesIdSortedByName(self):
         if self.__games_by_name is None:
-            l1, l2, l3  = [], [], []
+            l1, l2, l3 = [], [], []
             for id, gi in self.__games.items():
-                name = gi.name #.lower()
+                name = gi.name  # .lower()
                 l1.append((name, id))
                 if gi.name != gi.short_name:
-                    name = gi.short_name #.lower()
+                    name = gi.short_name  # .lower()
                 l2.append((name, id))
                 for n in gi.altnames:
-                    name = n #.lower()
+                    name = n  # .lower()
                     l3.append((name, id, n))
             l1.sort()
             l2.sort()
@@ -650,11 +778,15 @@ def registerGame(gameinfo):
     return gameinfo
 
 
+def hideGame(game):
+    game.gameinfo.si.game_type = GI.GT_HIDDEN
+    registerGame(game.gameinfo)
+
+
 def loadGame(modname, filename, check_game=False):
-    ##print "load game", modname, filename
+    # print "load game", modname, filename
     GAME_DB.check_game = check_game
     GAME_DB.current_filename = filename
-    module = imp.load_source(modname, filename)
-    ##execfile(filename, globals(), globals())
+    imp.load_source(modname, filename)
+    # execfile(filename, globals(), globals())
     GAME_DB.current_filename = None
-
