@@ -21,31 +21,26 @@
 #
 # ---------------------------------------------------------------------------##
 
-# imports
-
-# PySol imports
+from pysollib.game import Game
+from pysollib.gamedb import GI, GameInfo, registerGame
+from pysollib.games.numerica import Numerica_Hint
+from pysollib.layout import Layout
 from pysollib.mygettext import _
-from pysollib.gamedb import registerGame, GameInfo, GI
-from pysollib.util import ACE, ANY_RANK, ANY_SUIT, KING, QUEEN
 from pysollib.stack import \
         AbstractFoundationStack, \
         BasicRowStack, \
         DealRowTalonStack, \
         OpenStack, \
         OpenTalonStack, \
+        RK_FoundationStack, \
         RedealTalonStack, \
         ReserveStack, \
-        RK_FoundationStack, \
         SS_FoundationStack, \
         Stack, \
         StackWrapper, \
         WasteStack, \
         WasteTalonStack
-
-from pysollib.game import Game
-from pysollib.layout import Layout
-
-from pysollib.games.numerica import Numerica_Hint
+from pysollib.util import ACE, ANY_RANK, ANY_SUIT, KING, QUEEN
 
 
 # ************************************************************************
@@ -631,7 +626,7 @@ registerGame(GameInfo(553, Scuffle, "Scuffle",
 registerGame(GameInfo(560, DoubleAcquaintance, "Double Acquaintance",
                       GI.GT_NUMERICA, 2, 2, GI.SL_BALANCED))
 registerGame(GameInfo(569, Primrose, "Primrose",
-                      GI.GT_NUMERICA, 2, 8, GI.SL_BALANCED))
+                      GI.GT_NUMERICA | GI.GT_OPEN, 2, 8, GI.SL_BALANCED))
 registerGame(GameInfo(636, StrategyPlus, "Strategy +",
                       GI.GT_NUMERICA, 1, 0, GI.SL_SKILL))
 registerGame(GameInfo(688, Formic, "Formic",
