@@ -49,8 +49,8 @@ from pysollib.stack import \
         WasteStack, \
         WasteTalonStack, \
         isSameSuitSequence
-from pysollib.util import ACE, ANY_RANK, ANY_SUIT, KING, NO_RANK, RANKS, \
-        SUITS, \
+from pysollib.util import ACE, ANY_RANK, ANY_SUIT, DIAMOND, KING, NO_RANK,\
+        RANKS, SUITS, \
         UNLIMITED_REDEALS
 
 
@@ -620,9 +620,6 @@ class Uintah(Game):
 # * Diamond Mine
 # ************************************************************************
 
-DIAMOND = 3
-
-
 class DiamondMine_RowStack(RK_RowStack):
     def acceptsCards(self, from_stack, cards):
         if not RK_RowStack.acceptsCards(self, from_stack, cards):
@@ -803,6 +800,9 @@ class Vague(Game):
     Foundation_Classes = [StackWrapper(SS_FoundationStack,
                                        base_rank=ANY_RANK, mod=13)]
 
+    SEPARATE_FOUNDATIONS = True
+    SPREAD_FOUNDATION = False
+
     def createGame(self, rows=3, columns=6):
         layout, s = Layout(self), self.s
         decks = self.gameinfo.decks
@@ -815,9 +815,19 @@ class Vague(Game):
 
         x, y = layout.XM+2*layout.XS, layout.YM
         for found in self.Foundation_Classes:
-            for i in range(4):
-                s.foundations.append(found(x, y, self, suit=i))
-                x += layout.XS
+            if self.SEPARATE_FOUNDATIONS:
+                for i in range(4):
+                    s.foundations.append(found(x, y, self, suit=i))
+                    x += layout.XS
+            else:
+                s.foundations.append(found(x, y, self, suit=ANY_SUIT))
+                if self.SPREAD_FOUNDATION:
+                    w1, w2 = 6 * layout.XS + layout.XM, 2 * layout.XS
+
+                    totalcards = self.gameinfo.ncards
+                    if w2 + totalcards * layout.XOFFSET > w1:
+                        layout.XOFFSET = int((w1 - w2) / totalcards)
+                    s.foundations[0].CARD_XOFFSET = layout.XOFFSET
 
         y = layout.YM+layout.YS
         for i in range(rows):
@@ -864,6 +874,48 @@ class ThirtyTwoCards(Vague):
         self._startAndDealRow()
 
 
+# ************************************************************************
+# * Sticko
+# ************************************************************************
+
+class Sticko_Foundation(AbstractFoundationStack):
+    def acceptsCards(self, from_stack, cards):
+        r1, r2 = self.cards[-1].rank, cards[0].rank
+        s1, s2 = self.cards[-1].suit, cards[0].suit
+        c1, c2 = self.cards[-1].color, cards[0].color
+
+        # Increase rank, same suit
+        if ((r2 == r1 + 1 or (r2 == ACE and r1 == KING)
+             or (r2 == 6 and r1 == ACE)) and s1 == s2):
+            return True
+
+        # Decrease rank, different suit but same color
+        if ((r1 == r2 + 1 or (r1 == ACE and r2 == KING)
+             or (r1 == 6 and r2 == ACE)) and s1 != s2 and c1 == c2):
+            return True
+
+        # Same rank, different color
+        if r1 == r2 and c1 != c2:
+            return True
+
+        return False
+
+
+class Sticko(Vague):
+    Foundation_Classes = [StackWrapper(Sticko_Foundation,
+                                       max_cards=32, )]
+    SEPARATE_FOUNDATIONS = False
+    SPREAD_FOUNDATION = True
+
+    def createGame(self):
+        Vague.createGame(self, rows=2, columns=8)
+
+    def startGame(self):
+        self._startAndDealRow()
+        self.s.talon.flipMove()
+        self.s.talon.moveMove(1, self.s.foundations[0])
+
+
 # ************************************************************************
 # * Devil's Solitaire
 # ************************************************************************
@@ -1234,9 +1286,11 @@ registerGame(GameInfo(432, Robert, "Robert",
 registerGame(GameInfo(551, DiamondMine, "Diamond Mine",
                       GI.GT_1DECK_TYPE, 1, 0, GI.SL_BALANCED))
 registerGame(GameInfo(661, Dolphin, "Dolphin",
-                      GI.GT_GOLF | GI.GT_ORIGINAL, 1, 0, GI.SL_MOSTLY_SKILL))
+                      GI.GT_GOLF | GI.GT_OPEN | GI.GT_ORIGINAL, 1, 0,
+                      GI.SL_MOSTLY_SKILL))
 registerGame(GameInfo(662, DoubleDolphin, "Double Dolphin",
-                      GI.GT_GOLF | GI.GT_ORIGINAL, 2, 0, GI.SL_MOSTLY_SKILL))
+                      GI.GT_GOLF | GI.GT_OPEN | GI.GT_ORIGINAL, 2, 0,
+                      GI.SL_MOSTLY_SKILL))
 registerGame(GameInfo(709, Waterfall, "Waterfall",
                       GI.GT_2DECK_TYPE | GI.GT_ORIGINAL, 2, 0,
                       GI.SL_MOSTLY_SKILL))
@@ -1252,7 +1306,8 @@ registerGame(GameInfo(731, ThreeFirTrees, "Three Fir-trees",
 registerGame(GameInfo(733, NapoleonTakesMoscow, "Napoleon Takes Moscow",
                       GI.GT_2DECK_TYPE, 2, 2, GI.SL_BALANCED))
 registerGame(GameInfo(734, NapoleonLeavesMoscow, "Napoleon Leaves Moscow",
-                      GI.GT_2DECK_TYPE, 2, 2, GI.SL_BALANCED))
+                      GI.GT_2DECK_TYPE, 2, 2, GI.SL_BALANCED,
+                      altnames=("Napoleon at Friedland",)))
 registerGame(GameInfo(749, Flake, "Flake",
                       GI.GT_GOLF | GI.GT_OPEN | GI.GT_ORIGINAL,
                       1, 0, GI.SL_MOSTLY_SKILL))
@@ -1272,3 +1327,6 @@ registerGame(GameInfo(777, DoubleGolf, "Double Golf",
 registerGame(GameInfo(783, Uintah, "Uintah",
                       GI.GT_GOLF, 1, UNLIMITED_REDEALS,
                       GI.SL_MOSTLY_LUCK))
+registerGame(GameInfo(812, Sticko, "Sticko",
+                      GI.GT_1DECK_TYPE, 1, 0, GI.SL_BALANCED,
+                      ranks=(0, 6, 7, 8, 9, 10, 11, 12)))
