@@ -21,28 +21,17 @@
 #
 # ---------------------------------------------------------------------------##
 
-# imports
-
-# PySol imports
-from pysollib.mygettext import _
-from pysollib.gamedb import registerGame, GameInfo, GI
 from pysollib.game import Game
-from pysollib.layout import Layout
+from pysollib.gamedb import GI, GameInfo, registerGame
 from pysollib.hint import CautiousDefaultHint
-
-
-# from pysollib.util import
-
+from pysollib.layout import Layout
+from pysollib.mygettext import _
 from pysollib.stack import \
         OpenStack, \
         SS_FoundationStack, \
         Stack, \
         WasteTalonStack
 
-# ************************************************************************
-# *
-# ************************************************************************
-
 
 class LarasGame_Hint(CautiousDefaultHint):
     pass
@@ -463,4 +452,4 @@ registerGame(GameInfo(37, LarasGame, "Lara's Game",
 registerGame(GameInfo(13006, RelaxedLarasGame, "Lara's Game Relaxed",
                       GI.GT_2DECK_TYPE, 2, 1, GI.SL_BALANCED))
 registerGame(GameInfo(13007, DoubleLarasGame, "Lara's Game Doubled",
-                      GI.GT_2DECK_TYPE, 4, 2, GI.SL_BALANCED))
+                      GI.GT_4DECK_TYPE, 4, 2, GI.SL_BALANCED))
