@@ -153,10 +153,7 @@ class Montana_RowStack(BasicRowStack):
             return self.quickPlayHandler(event)
         return BasicRowStack.clickHandler(self, event)
 
-    # bottom to get events for an empty stack
-    prepareBottom = Stack.prepareInvisibleBottom
-
-    getBottomImage = Stack._getReserveBottomImage
+    getBottomImage = Stack._getBlankBottomImage
 
 
 class Montana(Game):
@@ -663,9 +660,8 @@ registerGame(GameInfo(275, Galary, "Galary",
                       GI.GT_MONTANA | GI.GT_OPEN | GI.GT_ORIGINAL, 1, 2,
                       GI.SL_MOSTLY_SKILL))
 registerGame(GameInfo(276, Moonlight, "Moonlight",
-                      GI.GT_MONTANA | GI.GT_OPEN | GI.GT_ORIGINAL, 1, 2,
-                      GI.SL_MOSTLY_SKILL,
-                      si={"ncards": 48}))
+                      GI.GT_MONTANA | GI.GT_OPEN, 1, 2, GI.SL_MOSTLY_SKILL,
+                      si={"ncards": 48}, altnames="Free Parking"))
 registerGame(GameInfo(380, Jungle, "Jungle",
                       GI.GT_MONTANA | GI.GT_OPEN, 1, 1, GI.SL_MOSTLY_SKILL))
 registerGame(GameInfo(381, SpacesAndAces, "Spaces and Aces",
