@@ -24,7 +24,7 @@
 
 import os
 
-from pysollib.mfxutil import Image, ImageTk, USE_PIL
+from pysollib.mfxutil import Image, ImageTk, USE_PIL, print_err
 from pysollib.pysoltk import copyImage, createBottom, createImage, loadImage
 from pysollib.pysoltk import shadowImage
 from pysollib.resource import CSI
@@ -80,7 +80,7 @@ class Images:
         # print '__loadCard:', filename
         f = os.path.join(self.cs.dir, filename)
         if not os.path.exists(f):
-            print('card image path %s does not exist' % (f))
+            print_err('card image path %s does not exist' % f)
             return None
         try:
             img = loadImage(file=f)
@@ -180,7 +180,12 @@ class Images:
         for name in self.cs.backnames:
             if name:
                 im = self.__loadCard(name)
-                self.__addBack(im, name)
+                if im:
+                    self.__addBack(im, name)
+                else:
+                    print_err('in {cs_dir}/config.txt: card back "{fname}" '
+                              'does not exist'.format(
+                                  cs_dir=self.cs.dir, fname=name))
         if progress:
             progress.update(step=1)
         # load bottoms
@@ -373,8 +378,8 @@ class Images:
             return
         r = self.reduced
         if r > 1:
-            self.CARD_XOFFSET = max(10//r, cs.CARD_XOFFSET)
-            self.CARD_YOFFSET = max(10//r, cs.CARD_YOFFSET)
+            self.CARD_XOFFSET = max(10, cs.CARD_XOFFSET // r)
+            self.CARD_YOFFSET = max(10, cs.CARD_YOFFSET // r)
         else:
             self.CARD_XOFFSET = cs.CARD_XOFFSET
             self.CARD_YOFFSET = cs.CARD_YOFFSET
@@ -469,6 +474,10 @@ class Images:
 
 class SubsampledImages(Images):
     def __init__(self, images, r=2):
+        size_cap = 100
+        if images.CARDW // r > size_cap or images.CARDH // r > size_cap:
+            r = max(images.CARDW, images.CARDH) // size_cap
+
         Images.__init__(self, None, images.cs, r=r)
         self._card = self._subsample(images._card, r)
         self._bottom_positive = self._subsample(images._bottom_positive, r)
@@ -477,6 +486,7 @@ class SubsampledImages(Images):
         self._letter_negative = self._subsample(images._letter_negative, r)
         self._bottom = self._bottom_positive
         self._letter = self._letter_positive
+
         #
         for _back in images._back:
             if _back is None:
