@@ -589,6 +589,11 @@ class OptionsMenuDialog(LMenuDialog):
                               self.menubar.tkopt.shisen_show_hint,
                               self.menubar.mOptShisenShowHint)
 
+            self.addCheckNode(tv, rg,
+                              _('Deal all cards (in Accordion type games)'),
+                              self.menubar.tkopt.accordion_deal_all,
+                              self.menubar.mOptAccordionDealAll)
+
             # submenu.add_separator()
 
         # -------------------------------------------
@@ -865,20 +870,29 @@ class OptionsMenuDialog(LMenuDialog):
                     self.menubar.mOptTableColor)
 
             rg1 = tv.add_node(
-                LTreeNode(text=_('Tiles and Images')), rg)
+                LTreeNode(text=_('Textures')), rg)
+            rg2 = tv.add_node(
+                LTreeNode(text=_('Images')), rg)
 
-            if rg1:
+            if rg1 or rg2:
                 tm = self.app.tabletile_manager
                 # cnt = tm.len()
                 i = 1
                 while True:
                     ti = tm.get(i)
+
                     if ti is None:
                         break
-                    self.addRadioNode(tv, rg1,
-                                      ti.name,
-                                      self.menubar.tkopt.tabletile, i,
-                                      self.menubar.mOptTileSet)
+                    if ti.save_aspect == 0 and ti.stretch == 0 and rg1:
+                        self.addRadioNode(tv, rg1,
+                                          ti.name,
+                                          self.menubar.tkopt.tabletile, i,
+                                          self.menubar.mOptTileSet)
+                    if (ti.save_aspect == 1 or ti.stretch == 1) and rg2:
+                        self.addRadioNode(tv, rg2,
+                                          ti.name,
+                                          self.menubar.tkopt.tabletile, i,
+                                          self.menubar.mOptTileSet)
                     i += 1
 
         # -------------------------------------------
@@ -1097,7 +1111,7 @@ class HelpMenuDialog(LMenuDialog):
                 command=self.make_help_command(self.menubar.mHelp)))
         tv.add_node(
             LTreeNode(
-                text=_('How to play'),
+                text=_('How to use PySol'),
                 command=self.make_help_command(self.menubar.mHelpHowToPlay)))
         tv.add_node(
             LTreeNode(
@@ -1238,6 +1252,7 @@ class PysolMenubarTk:
             highlight_not_matching=BooleanVar(),
             mahjongg_show_removed=BooleanVar(),
             shisen_show_hint=BooleanVar(),
+            accordion_deal_all=BooleanVar(),
             sound=BooleanVar(),
             sound_sample_volume=IntVar(),
             sound_music_volume=IntVar(),
@@ -1299,6 +1314,7 @@ class PysolMenubarTk:
         tkopt.shade_filled_stacks.set(opt.shade_filled_stacks)
         tkopt.mahjongg_show_removed.set(opt.mahjongg_show_removed)
         tkopt.shisen_show_hint.set(opt.shisen_show_hint)
+        tkopt.accordion_deal_all.set(opt.accordion_deal_all)
         tkopt.sound.set(opt.sound)
         tkopt.sound_sample_volume.set(opt.sound_sample_volume)
         tkopt.sound_music_volume.set(opt.sound_music_volume)
@@ -2096,6 +2112,12 @@ the next time you restart the %(app)s""") % {'app': TITLE})
         self.app.opt.shisen_show_hint = self.tkopt.shisen_show_hint.get()
         # self.game.updateMenus()
 
+    def mOptAccordionDealAll(self, *args):
+        if self._cancelDrag(break_pause=False):
+            return
+        self.app.opt.accordion_deal_all = self.tkopt.accordion_deal_all.get()
+        # self.game.updateMenus()
+
     def mOptCardset(self, *event):
         if self._cancelDrag(break_pause=False):
             return
