@@ -111,7 +111,6 @@ mouse_type = string
 mouse_undo = boolean
 negative_bottom = boolean
 randomize_place = boolean
-save_cardsets = boolean
 dragcursor = boolean
 save_games_geometry = boolean
 game_geometry = int_list(min=2, max=2)
@@ -121,6 +120,7 @@ sound_sample_volume = integer(0, 128)
 sound_sample_buffer_size = integer(1, 4)
 music = boolean
 tabletile_name = string
+center_layout = boolean
 recent_gameid = int_list
 favorite_gameid = int_list
 visible_buttons = string_list
@@ -199,6 +199,7 @@ scale_cards = boolean
 scale_x = float
 scale_y = float
 auto_scale = boolean
+spread_stacks = boolean
 preserve_aspect_ratio = boolean
 '''.splitlines()
 
@@ -224,6 +225,7 @@ class Options:
         ('mahjongg_create_solvable', 'int'),
         ('shisen_show_hint', 'bool'),
         ('shisen_show_matching', 'bool'),
+        ('accordion_deal_all', 'bool'),
         ('animations', 'int'),
         ('redeal_animation', 'bool'),
         ('win_animation', 'bool'),
@@ -255,7 +257,7 @@ class Options:
         ('mouse_undo', 'bool'),
         ('negative_bottom', 'bool'),
         ('randomize_place', 'bool'),
-        ('save_cardsets', 'bool'),
+        # ('save_cardsets', 'bool'),
         ('dragcursor', 'bool'),
         ('save_games_geometry', 'bool'),
         ('sound', 'bool'),
@@ -265,6 +267,7 @@ class Options:
         ('sound_sample_buffer_size', 'int'),
         ('music', 'bool'),
         ('tabletile_name', 'str'),
+        ('center_layout', 'bool'),
         ('translate_game_names', 'bool'),
         ('solver_presets', 'list'),
         ('solver_show_progress', 'bool'),
@@ -305,6 +308,7 @@ class Options:
         self.highlight_not_matching = True
         self.mahjongg_show_removed = False
         self.mahjongg_create_solvable = 2  # 0 - none, 1 - easy, 2 - hard
+        self.accordion_deal_all = True
         if TOOLKIT == 'kivy':
             self.mahjongg_create_solvable = 1  # 0 - none, 1 - easy, 2 - hard
         self.shisen_show_hint = True
@@ -432,7 +436,7 @@ class Options:
         self.offsets = {}           # cards offsets
         #
         self.randomize_place = False
-        self.save_cardsets = True
+        # self.save_cardsets = True
         self.dragcursor = True
         #
         self.scale_cards = False
