@@ -25,7 +25,6 @@
 # imports
 import os
 import traceback
-
 from threading import Thread
 
 try:
@@ -226,7 +225,7 @@ class PysolSoundServerModuleClient(AbstractAudioClient):
         return -1
 
     def playContinuousMusic(self, music_list):
-        if self.audiodev is None or not self.app:
+        if self.audiodev is None or not self.app or not self.app.opt.music:
             return
         try:
             loop = 999999
@@ -249,7 +248,8 @@ class PysolSoundServerModuleClient(AbstractAudioClient):
         s, m = 0, 0
         if self.app.opt.sound:
             s = self.app.opt.sound_sample_volume
-            m = self.app.opt.sound_music_volume
+            if self.app.opt.music:
+                m = self.app.opt.sound_music_volume
         try:
             self.cmd("setwavvol %d" % s)
             self.cmd("setmusvol %d" % m)
@@ -566,10 +566,10 @@ class PyGameAudioClient(AbstractAudioClient):
         if not music_list:
             return
         while True:
-            if not self.music:
+            if not self.music or not self.app.opt.music:
                 break
             for m in music_list:
-                if not self.music:
+                if not self.music or not self.app.opt.music:
                     break
                 vol = self.app.opt.sound_music_volume/128.0
                 try:
@@ -604,7 +604,8 @@ class PyGameAudioClient(AbstractAudioClient):
         th.start()
 
     def updateSettings(self):
-        if not self.app.opt.sound or self.app.opt.sound_music_volume == 0:
+        if (not self.app.opt.sound or not self.app.opt.music or
+                self.app.opt.sound_music_volume == 0):
             if self.music:
                 self.music.stop()
                 self.music = None
