@@ -396,7 +396,7 @@ class SelectGameDialogWithPreview(MfxDialog):
                 gamerandom=self.app.gamerandom,
                 gdb=self.app.gdb,
                 gimages=self.app.gimages,
-                images=self.app.subsampled_images,
+                images=None,
                 menubar=None,
                 miscrandom=self.app.miscrandom,
                 opt=self.app.opt.copy(),
@@ -412,6 +412,19 @@ class SelectGameDialogWithPreview(MfxDialog):
             self.preview_app.opt.shadow = 0
             self.preview_app.opt.shade = 0
         #
+
+        c = self.app.cardsets_cache.get(gi.category)
+        if not c:
+            cardset = self.app.cardset_manager.getByName(
+                self.app.opt.cardset[gi.category][0])
+            self.app.loadCardset(cardset, id=gi.category,
+                                 tocache=True, noprogress=True)
+            c = self.app.cardsets_cache.get(gi.category)
+        if c:
+            self.preview_app.images = c[2]
+        else:
+            self.preview_app.images = self.app.subsampled_images
+
         self.preview_app.audio = None    # turn off audio for initial dealing
         if animations >= 0:
             self.preview_app.opt.animations = animations
@@ -422,7 +435,7 @@ class SelectGameDialogWithPreview(MfxDialog):
         # self.top.wm_title(
         #   "Select Game - " + self.app.getGameTitleName(gameid))
         title = self.app.getGameTitleName(gameid)
-        self.set_title(_("Playable Preview - %(game)s") % {'game': title})
+        self.set_title(_("Select Game - %(game)s") % {'game': title})
         #
         self.preview_game = gi.gameclass(gi)
         self.preview_game.createPreview(self.preview_app)
