@@ -21,30 +21,24 @@
 #
 # ---------------------------------------------------------------------------
 
-# imports
-import sys
+import locale
 import os
 import time
-import locale
-from six.moves import tkinter
-from . import ttk
-from six.moves import tkinter_font
-from six import PY2
 import traceback
 
-# PySol imports
+from pysollib.mfxutil import KwStruct, destruct, kwdefault, openURL
 from pysollib.mygettext import _
-from pysollib.mfxutil import destruct, kwdefault, KwStruct, openURL
 from pysollib.settings import WIN_SYSTEM
-
-# Toolkit imports
+from pysollib.ui.tktile.tkcanvas import MfxCanvas
 from pysollib.ui.tktile.tkutil import after, after_cancel
 from pysollib.ui.tktile.tkutil import bind, unbind_destroy
 from pysollib.ui.tktile.tkutil import makeToplevel, setTransient
-from pysollib.ui.tktile.tkcanvas import MfxCanvas
 
-if sys.version_info > (3,):
-    unicode = str
+import six
+from six import PY2
+from six.moves import tkinter
+from six.moves import tkinter_font
+from six.moves import tkinter_ttk as ttk
 
 # ************************************************************************
 # * abstract base class for the dialogs in this module
@@ -125,9 +119,9 @@ class MfxDialog:  # ex. _ToplevelDialog
             key = event.char
             try:
                 if os.name == 'nt':
-                    key = unicode(key, locale.getpreferredencoding())
+                    key = six.text_type(key, locale.getpreferredencoding())
                 else:
-                    key = unicode(key, 'utf-8')
+                    key = six.text_type(key, 'utf-8')
             except Exception:
                 pass
             else:
@@ -294,7 +288,7 @@ class MfxExceptionDialog(MfxMessageDialog):
         else:
             t = str(ex)
         if PY2:
-            t = unicode(t, errors='replace')
+            t = six.text_type(t, errors='replace')
         kw.text = text + t
         MfxMessageDialog.__init__(self, parent, title, **kw.getKw())
 
@@ -318,18 +312,19 @@ class PysolAboutDialog(MfxMessageDialog):
                         width=kw.width)
         msg.pack(fill='both', expand=True)
 
-        if sys.version_info >= (2, 4):
-            # font_name = msg.lookup('TLabel', 'font')
-            font_name = 'TkDefaultFont'
-            font = tkinter_font.Font(parent, name=font_name, exists=True)
-            font = font.copy()
-        else:
-            font = tkinter_font.Font(parent, app.getFont('default'))
+        # font_name = msg.lookup('TLabel', 'font')
+        font_name = 'TkDefaultFont'
+        font = tkinter_font.Font(parent, name=font_name, exists=True)
+        font = font.copy()
         font.configure(underline=True)
         url_label = ttk.Label(frame, text=kw.url, font=font,
                               foreground='blue', cursor='hand2')
         url_label.pack()
-        url_label.bind('<1>', self._urlClicked)
+        from pysollib.options import calcCustomMouseButtonsBinding
+        url_label.bind(
+            calcCustomMouseButtonsBinding('<{mouse_button1}>'),
+            self._urlClicked
+        )
         #
         focus = self.createButtons(bottom_frame, kw)
         self.mainloop(focus, kw.timeout)
