@@ -21,29 +21,23 @@
 #
 # ---------------------------------------------------------------------------##
 
-# imports
 import os
-from six.moves import tkinter
-from . import ttk
 
-# PySol imports
+from pysollib.mfxutil import Image, ImageOps, ImageTk
 from pysollib.mygettext import _, n_
-from pysollib.mfxutil import Image, ImageTk, ImageOps
-from pysollib.util import IMAGE_EXTENSIONS
 from pysollib.settings import TITLE
+from pysollib.ui.tktile.menubar import MfxMenu, createToolbarMenu
+from pysollib.ui.tktile.tkconst import EVENT_HANDLED
+from pysollib.ui.tktile.tkutil import loadImage
+from pysollib.util import IMAGE_EXTENSIONS
 from pysollib.winsystems import TkSettings
 
-# Toolkit imports
-from pysollib.ui.tktile.tkconst import EVENT_HANDLED
+from six.moves import tkinter
+from six.moves import tkinter_ttk as ttk
+
 from .tkwidget import MfxTooltip
-from pysollib.ui.tktile.menubar import createToolbarMenu, MfxMenu
-from pysollib.ui.tktile.tkutil import loadImage
 
 
-# ************************************************************************
-# *
-# ************************************************************************
-
 class AbstractToolbarButton:
     def __init__(self, parent, toolbar, toolbar_name, position):
         self.toolbar = toolbar
@@ -79,16 +73,16 @@ class ToolbarCheckbutton(AbstractToolbarButton, ttk.Checkbutton):
     def __init__(self, parent, toolbar, toolbar_name, position, **kwargs):
         kwargs['style'] = 'Toolbutton'
         ttk.Checkbutton.__init__(self, parent, **kwargs)
-        AbstractToolbarButton.__init__(self, parent, toolbar,
-                                       toolbar_name, position)
+        AbstractToolbarButton.__init__(
+            self, parent, toolbar, toolbar_name, position)
 
 
 class ToolbarButton(AbstractToolbarButton, ttk.Button):
     def __init__(self, parent, toolbar, toolbar_name, position, **kwargs):
         kwargs['style'] = 'Toolbutton'
         ttk.Button.__init__(self, parent, **kwargs)
-        AbstractToolbarButton.__init__(self, parent, toolbar,
-                                       toolbar_name, position)
+        AbstractToolbarButton.__init__(
+            self, parent, toolbar, toolbar_name, position)
 
 
 class ToolbarSeparator(ttk.Separator):
@@ -164,6 +158,7 @@ class PysolToolbarTk:
 
     def __init__(self, top, menubar, dir,
                  size=0, relief='flat', compound='none'):
+        from pysollib.options import calcCustomMouseButtonsBinding
         self.top = top
         self.menubar = menubar
         self.side = -1
@@ -194,11 +189,14 @@ class PysolToolbarTk:
             (n_("Statistics"), self.mPlayerStats, _("View statistics")),
             (n_("Rules"),    self.mHelpRules, _("Rules for this game")),
             (None,           None,            None),
-            (n_("Quit"),     self.mQuit,      _("Quit ")+TITLE),
+            (n_("Quit"),     self.mQuit,      _("Quit %s") % TITLE),
                 ):
             if label is None:
                 sep = self._createSeparator()
-                sep.bind("<3>", self.rightclickHandler)
+                sep.bind(
+                    calcCustomMouseButtonsBinding("<{mouse_button3}>"),
+                    self.rightclickHandler
+                )
             elif label == 'Pause':
                 self._createButton(label, f, check=True, tooltip=t)
             else:
@@ -215,8 +213,14 @@ class PysolToolbarTk:
         self._createLabel("player", label=n_('Player'),
                           tooltip=_("Player options"))
         #
-        self.player_label.bind("<1>", self.mOptPlayerOptions)
-        self.frame.bind("<3>", self.rightclickHandler)
+        self.player_label.bind(
+            calcCustomMouseButtonsBinding("<{mouse_button1}>"),
+            self.mOptPlayerOptions
+        )
+        self.frame.bind(
+            calcCustomMouseButtonsBinding("<{mouse_button3}>"),
+            self.rightclickHandler
+        )
         #
         self.setCompound(compound, force=True)
 
@@ -459,8 +463,6 @@ class PysolToolbarTk:
         if self._busy():
             return EVENT_HANDLED
         if self.popup:
-            # print event.x, event.y, \
-            #       event.x_root, event.y_root, event.__dict__
             self.popup.tk_popup(event.x_root, event.y_root)
         return EVENT_HANDLED
 
