@@ -169,8 +169,10 @@ class PysolMenubarTkCommon:
             highlight_not_matching=tkinter.BooleanVar(),
             mahjongg_show_removed=tkinter.BooleanVar(),
             shisen_show_hint=tkinter.BooleanVar(),
+            accordion_deal_all=tkinter.BooleanVar(),
             sound=tkinter.BooleanVar(),
             auto_scale=tkinter.BooleanVar(),
+            preserve_aspect_ratio=tkinter.BooleanVar(),
             spread_stacks=tkinter.BooleanVar(),
             center_layout=tkinter.BooleanVar(),
             cardback=tkinter.IntVar(),
@@ -222,8 +224,10 @@ class PysolMenubarTkCommon:
         tkopt.shade_filled_stacks.set(opt.shade_filled_stacks)
         tkopt.mahjongg_show_removed.set(opt.mahjongg_show_removed)
         tkopt.shisen_show_hint.set(opt.shisen_show_hint)
+        tkopt.accordion_deal_all.set(opt.accordion_deal_all)
         tkopt.sound.set(opt.sound)
         tkopt.auto_scale.set(opt.auto_scale)
+        tkopt.preserve_aspect_ratio.set(opt.preserve_aspect_ratio)
         tkopt.spread_stacks.set(opt.spread_stacks)
         tkopt.center_layout.set(opt.center_layout)
         tkopt.cardback.set(self.app.cardset.backindex)
@@ -396,6 +400,9 @@ class PysolMenubarTkCommon:
         menu.add_command(
             label=n_("&Edit current game"),
             command=self.mWizardEdit)
+        menu.add_command(
+            label=n_("&Delete current game"),
+            command=self.mWizardDelete)
 
         menu = MfxMenu(self.menubar, label=n_("&Game"))
         menu.add_command(
@@ -516,6 +523,10 @@ class PysolMenubarTkCommon:
             label=n_("Show hint &arrow (in Shisen-Sho games)"),
             variable=self.tkopt.shisen_show_hint,
             command=self.mOptShisenShowHint)
+        submenu.add_checkbutton(
+            label=n_("&Deal all cards (in Accordion type games)"),
+            variable=self.tkopt.accordion_deal_all,
+            command=self.mOptAccordionDealAll)
         menu.add_separator()
         label = n_("&Sound...")
         menu.add_command(
@@ -529,9 +540,17 @@ class PysolMenubarTkCommon:
             submenu.add_command(
                 label=n_("&Decrease the card size"),
                 command=self.mDecreaseCardset, accelerator=m+"-")
+            submenu.add_command(
+                label=n_("&Reset the card size"),
+                command=self.mResetCardset)
+            submenu.add_separator()
             submenu.add_checkbutton(
                 label=n_("&Auto scaling"), variable=self.tkopt.auto_scale,
                 command=self.mOptAutoScale, accelerator=m+'0')
+            submenu.add_checkbutton(
+                label=n_("&Preserve aspect ratio"),
+                variable=self.tkopt.preserve_aspect_ratio,
+                command=self.mOptPreserveAspectRatio)
             submenu = MfxMenu(menu, label=n_("Card la&yout"))
             submenu.add_checkbutton(
                 label=n_("&Spread stacks"), variable=self.tkopt.spread_stacks,
@@ -662,7 +681,7 @@ class PysolMenubarTkCommon:
                 label=n_("&Contents"),
                 command=self.mHelp, accelerator=m+"F1")
         menu.add_command(
-            label=n_("&How to play"),
+            label=n_("&How to use PySol"),
             command=self.mHelpHowToPlay)
         menu.add_command(
             label=n_("&Rules for this game"),
@@ -926,7 +945,8 @@ class PysolMenubarTkCommon:
         self.updateGamesMenu(submenu, games)
 
     def _addSelectAllGameSubMenu(self, games, menu, command, variable):
-        menu = MfxMenu(menu, label=n_("&All games by name"))
+        if menu.name != "allgamesbyname":
+            menu = MfxMenu(menu, label=n_("&All games by name"))
         n, d = 0, self.cb_max
         i = 0
         while True:
@@ -1063,6 +1083,24 @@ class PysolMenubarTkCommon:
                 games.append(gi)
         self.updateGamesMenu(submenu, games)
 
+    def updateCustomGamesMenu(self):
+        menu = self.menupath[".menubar.select.customgames"][2]
+        menu2 = self.menupath[".menubar.select.allgamesbyname"][2]
+
+        def select_func_visible(gi):
+            return gi.si.game_type != GI.GT_HIDDEN
+
+        def select_func_custom(gi):
+            return gi.si.game_type == GI.GT_CUSTOM
+
+        games = list(map(self.app.gdb.get,
+                         self.app.gdb.getGamesIdSortedByName()))
+        games = list(filter(select_func_visible, games))
+        self.progress = False
+        self.updateGamesMenu(menu2, games)
+        games = list(filter(select_func_custom, games))
+        self.updateGamesMenu(menu, games)
+
     def updateBookmarkMenuState(self):
         state = self._getEnabledState
         mp1 = self.menupath.get(".menubar.edit.setbookmark")
@@ -1429,6 +1467,12 @@ Unsupported game for import.
         self.app.opt.shisen_show_hint = self.tkopt.shisen_show_hint.get()
         # self.game.updateMenus()
 
+    def mOptAccordionDealAll(self, *args):
+        if self._cancelDrag(break_pause=False):
+            return
+        self.app.opt.accordion_deal_all = self.tkopt.accordion_deal_all.get()
+        # self.game.updateMenus()
+
     def _updateCardSize(self):
         geom = (self.app.canvas.winfo_width(),
                 self.app.canvas.winfo_height())
@@ -1445,6 +1489,10 @@ Unsupported game for import.
             self.app.canvas.setInitialSize(w, h)
             self.app.top.wm_geometry("")    # cancel user-specified geometry
         # self.app.top.update_idletasks()
+        self.app.setTile(self.app.tabletile_index)
+        self.tkopt.tabletile.set(self.app.tabletile_index)
+
+        self.updateMenus()
 
     def mIncreaseCardset(self, *event):
         if self._cancelDrag(break_pause=True):
@@ -1476,6 +1524,16 @@ Unsupported game for import.
         self.tkopt.auto_scale.set(False)
         self._updateCardSize()
 
+    def mResetCardset(self, *event):
+        if self._cancelDrag(break_pause=True):
+            return
+        self.app.opt.scale_x = 1
+        self.app.opt.scale_y = 1
+
+        self.app.opt.auto_scale = False
+        self.tkopt.auto_scale.set(False)
+        self._updateCardSize()
+
     def mOptAutoScale(self, *event):
         if self._cancelDrag(break_pause=True):
             return
@@ -1490,6 +1548,15 @@ Unsupported game for import.
         self.tkopt.auto_scale.set(auto_scale)
         self._updateCardSize()
 
+    def mOptPreserveAspectRatio(self, *event):
+        if self._cancelDrag(break_pause=True):
+            return
+        preserve_aspect_ratio = not self.app.opt.preserve_aspect_ratio
+
+        self.app.opt.preserve_aspect_ratio = preserve_aspect_ratio
+        self.tkopt.preserve_aspect_ratio.set(preserve_aspect_ratio)
+        self._updateCardSize()
+
     def mOptSpreadStacks(self, *event):
         if self._cancelDrag(break_pause=True):
             return
@@ -1712,14 +1779,7 @@ Error while saving game.
                 return
 
             if SELECT_GAME_MENU:
-                menu = self.menupath[".menubar.select.customgames"][2]
-
-                def select_func(gi):
-                    return gi.si.game_type == GI.GT_CUSTOM
-                games = list(map(self.app.gdb.get,
-                                 self.app.gdb.getGamesIdSortedByName()))
-                games = list(filter(select_func, games))
-                self.updateGamesMenu(menu, games)
+                self.updateCustomGamesMenu()
 
             self.tkopt.gameid.set(gameid)
             self._mSelectGame(gameid, force=True)
@@ -1734,6 +1794,21 @@ Error while saving game.
             return
         self.wizardDialog(edit=True)
 
+    def mWizardDelete(self, *event):
+        if self._cancelDrag(break_pause=False):
+            return
+        if not self.game.areYouSure(_("Delete game"),
+                                    _("Delete the game "
+                                      + self.game.gameinfo.name + "?")):
+            return
+        from pysollib.wizardutil import delete_game
+        delete_game(self.game)
+        self.game.endGame()
+        self.game.quitGame(2)
+
+        if SELECT_GAME_MENU:
+            self.updateCustomGamesMenu()
+
     def toolbarConfig(self, w, v):
         if self._cancelDrag(break_pause=False):
             return
